@@ -340,11 +340,9 @@ public abstract class Matcher extends IntHolder {
                 // !begin_position:!
                 if (range > start) {
                     if (gpos > start) {
-                        if (gpos < range) {
-                            range = gpos + 1;
-                        } else {
-                            range = start + 1;
-                        }
+                        if (gpos < range) range = gpos + 1;
+                    } else {
+                        range = start + 1;
                     }
                 } else {
                     range = start;
@@ -390,11 +388,9 @@ public abstract class Matcher extends IntHolder {
                 // goto !begin_position;!
                 if (range > start) {
                     if (gpos > start) {
-                        if (gpos < range) {
-                            range = gpos + 1;
-                        } else {
-                            range = start + 1;
-                        }
+                        if (gpos < range) range = gpos + 1;
+                    } else {
+                        range = start + 1;
                     }
                 } else {
                     range = start;
